@@ -1,6 +1,7 @@
 package incus
 
 import (
+	"errors"
 	"fmt"
 	"net/url"
 
@@ -10,7 +11,7 @@ import (
 // GetNetworkPeerNames returns a list of network peer names.
 func (r *ProtocolIncus) GetNetworkPeerNames(networkName string) ([]string, error) {
 	if !r.HasExtension("network_peer") {
-		return nil, fmt.Errorf(`The server is missing the required "network_peer" API extension`)
+		return nil, errors.New(`The server is missing the required "network_peer" API extension`)
 	}
 
 	// Fetch the raw URL values.
@@ -28,7 +29,7 @@ func (r *ProtocolIncus) GetNetworkPeerNames(networkName string) ([]string, error
 // GetNetworkPeers returns a list of network peer structs.
 func (r *ProtocolIncus) GetNetworkPeers(networkName string) ([]api.NetworkPeer, error) {
 	if !r.HasExtension("network_peer") {
-		return nil, fmt.Errorf(`The server is missing the required "network_peer" API extension`)
+		return nil, errors.New(`The server is missing the required "network_peer" API extension`)
 	}
 
 	peers := []api.NetworkPeer{}
@@ -45,7 +46,7 @@ func (r *ProtocolIncus) GetNetworkPeers(networkName string) ([]api.NetworkPeer,
 // GetNetworkPeer returns a network peer entry for the provided network and peer name.
 func (r *ProtocolIncus) GetNetworkPeer(networkName string, peerName string) (*api.NetworkPeer, string, error) {
 	if !r.HasExtension("network_peer") {
-		return nil, "", fmt.Errorf(`The server is missing the required "network_peer" API extension`)
+		return nil, "", errors.New(`The server is missing the required "network_peer" API extension`)
 	}
 
 	peer := api.NetworkPeer{}
@@ -63,11 +64,11 @@ func (r *ProtocolIncus) GetNetworkPeer(networkName string, peerName string) (*ap
 // Returns true if the peer connection has been mutually created. Returns false if peering has been only initiated.
 func (r *ProtocolIncus) CreateNetworkPeer(networkName string, peer api.NetworkPeersPost) error {
 	if !r.HasExtension("network_peer") {
-		return fmt.Errorf(`The server is missing the required "network_peer" API extension`)
+		return errors.New(`The server is missing the required "network_peer" API extension`)
 	}
 
 	if peer.Type != "" && peer.Type != "local" && !r.HasExtension("network_integrations") {
-		return fmt.Errorf(`The server is missing the required "network_integrations" API extension`)
+		return errors.New(`The server is missing the required "network_integrations" API extension`)
 	}
 
 	// Send the request.
@@ -82,7 +83,7 @@ func (r *ProtocolIncus) CreateNetworkPeer(networkName string, peer api.NetworkPe
 // UpdateNetworkPeer updates the network peer to match the provided struct.
 func (r *ProtocolIncus) UpdateNetworkPeer(networkName string, peerName string, peer api.NetworkPeerPut, ETag string) error {
 	if !r.HasExtension("network_peer") {
-		return fmt.Errorf(`The server is missing the required "network_peer" API extension`)
+		return errors.New(`The server is missing the required "network_peer" API extension`)
 	}
 
 	// Send the request.
@@ -97,7 +98,7 @@ func (r *ProtocolIncus) UpdateNetworkPeer(networkName string, peerName string, p
 // DeleteNetworkPeer deletes an existing network peer.
 func (r *ProtocolIncus) DeleteNetworkPeer(networkName string, peerName string) error {
 	if !r.HasExtension("network_peer") {
-		return fmt.Errorf(`The server is missing the required "network_peer" API extension`)
+		return errors.New(`The server is missing the required "network_peer" API extension`)
 	}
 
 	// Send the request.
