@@ -1,19 +1,28 @@
 package main
 
 import (
+	"fmt"
 	"os"
 
 	"github.com/spf13/cobra"
 
 	"github.com/lxc/incus/v6/internal/version"
+	"github.com/lxc/incus/v6/shared/logger"
 )
 
 type cmdGlobal struct {
-	flagHelp    bool
-	flagVersion bool
+	flagHelp       bool
+	flagVersion    bool
+	flagLogVerbose bool
+	flagLogDebug   bool
 }
 
-func main() {
+// PreRun runs immediately prior to the main Run function.
+func (c *cmdGlobal) PreRun(cmd *cobra.Command, args []string) error {
+	return logger.InitLogger("", "", c.flagLogVerbose, c.flagLogDebug, nil)
+}
+
+func run() error {
 	// daemon command (main)
 	daemonCmd := cmdDaemon{}
 	app := daemonCmd.Command()
@@ -32,14 +41,22 @@ func main() {
 	globalCmd := cmdGlobal{}
 	app.PersistentFlags().BoolVar(&globalCmd.flagVersion, "version", false, "Print version number")
 	app.PersistentFlags().BoolVarP(&globalCmd.flagHelp, "help", "h", false, "Print help")
+	app.PersistentFlags().BoolVarP(&globalCmd.flagLogVerbose, "verbose", "v", false, "Show all information messages")
+	app.PersistentFlags().BoolVarP(&globalCmd.flagLogDebug, "debug", "d", false, "Show debug messages")
+	app.PersistentPreRunE = globalCmd.PreRun
 
 	// Version handling
 	app.SetVersionTemplate("{{.Version}}\n")
 	app.Version = version.Version
 
 	// Run the main command and handle errors
-	err := app.Execute()
+	return app.Execute()
+}
+
+func main() {
+	err := run()
 	if err != nil {
+		fmt.Fprintf(os.Stderr, "Error: %v", err)
 		os.Exit(1)
 	}
 }
