@@ -1,7 +1,9 @@
 package main
 
 import (
+	"errors"
 	"fmt"
+	"maps"
 	"strings"
 
 	"github.com/spf13/cobra"
@@ -33,6 +35,7 @@ type cmdCopy struct {
 	flagAllowInconsistent   bool
 }
 
+// Command returns a cobra.Command for use with (*cobra.Command).AddCommand.
 func (c *cmdCopy) Command() *cobra.Command {
 	cmd := &cobra.Command{}
 	cmd.Use = usage("copy", i18n.G("[<remote>:]<source>[/<snapshot>] [[<remote>:]<destination>]"))
@@ -65,7 +68,7 @@ The pull transfer mode is the default as it is compatible with all server versio
 	cmd.Flags().BoolVar(&c.flagRefreshExcludeOlder, "refresh-exclude-older", false, i18n.G("During incremental copy, exclude source snapshots earlier than latest target snapshot"))
 	cmd.Flags().BoolVar(&c.flagAllowInconsistent, "allow-inconsistent", false, i18n.G("Ignore copy errors for volatile files"))
 
-	cmd.ValidArgsFunction = func(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective) {
+	cmd.ValidArgsFunction = func(_ *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective) {
 		if len(args) == 0 {
 			return c.global.cmpInstances(toComplete)
 		}
@@ -95,12 +98,12 @@ func (c *cmdCopy) copyInstance(conf *config.Config, sourceResource string, destR
 
 	// Make sure we have an instance or snapshot name
 	if sourceName == "" {
-		return fmt.Errorf(i18n.G("You must specify a source instance name"))
+		return errors.New(i18n.G("You must specify a source instance name"))
 	}
 
 	// Don't allow refreshing without profiles.
 	if c.flagRefresh && c.flagNoProfiles {
-		return fmt.Errorf(i18n.G("--no-profiles cannot be used with --refresh"))
+		return errors.New(i18n.G("--no-profiles cannot be used with --refresh"))
 	}
 
 	// If the instance is being copied to a different remote and no destination name is
@@ -112,7 +115,7 @@ func (c *cmdCopy) copyInstance(conf *config.Config, sourceResource string, destR
 
 	// Ensure that a destination name is provided.
 	if destName == "" {
-		return fmt.Errorf(i18n.G("You must specify a destination instance name"))
+		return errors.New(i18n.G("You must specify a destination instance name"))
 	}
 
 	// Connect to the source host
@@ -141,7 +144,7 @@ func (c *cmdCopy) copyInstance(conf *config.Config, sourceResource string, destR
 
 	// Confirm that --target is only used with a cluster
 	if c.flagTarget != "" && !dest.IsClustered() {
-		return fmt.Errorf(i18n.G("To use --target, the destination remote must be a cluster"))
+		return errors.New(i18n.G("To use --target, the destination remote must be a cluster"))
 	}
 
 	// Parse the config overrides
@@ -166,7 +169,7 @@ func (c *cmdCopy) copyInstance(conf *config.Config, sourceResource string, destR
 
 	if instance.IsSnapshot(sourceName) {
 		if instanceOnly {
-			return fmt.Errorf(i18n.G("--instance-only can't be passed when the source is a snapshot"))
+			return errors.New(i18n.G("--instance-only can't be passed when the source is a snapshot"))
 		}
 
 		// Prepare the instance creation request
@@ -177,7 +180,7 @@ func (c *cmdCopy) copyInstance(conf *config.Config, sourceResource string, destR
 		}
 
 		if c.flagRefresh {
-			return fmt.Errorf(i18n.G("--refresh can only be used with instances"))
+			return errors.New(i18n.G("--refresh can only be used with instances"))
 		}
 
 		// Copy of a snapshot into a new instance
@@ -195,9 +198,7 @@ func (c *cmdCopy) copyInstance(conf *config.Config, sourceResource string, destR
 		}
 
 		// Allow setting additional config keys
-		for key, value := range configMap {
-			entry.Config[key] = value
-		}
+		maps.Copy(entry.Config, configMap)
 
 		// Allow setting device overrides
 		for k, m := range deviceMap {
@@ -212,22 +213,18 @@ func (c *cmdCopy) copyInstance(conf *config.Config, sourceResource string, destR
 				continue
 			}
 
-			for key, value := range m {
-				entry.Devices[k][key] = value
-			}
+			maps.Copy(entry.Devices[k], m)
 		}
 
 		// Allow overriding the ephemeral status
-		if ephemeral == 1 {
+		switch ephemeral {
+		case 1:
 			entry.Ephemeral = true
-		} else if ephemeral == 0 {
+		case 0:
 			entry.Ephemeral = false
 		}
 
 		rootDiskDeviceKey, _, _ := instance.GetRootDiskDevice(entry.Devices)
-		if err != nil {
-			return err
-		}
 
 		if rootDiskDeviceKey != "" && pool != "" {
 			entry.Devices[rootDiskDeviceKey]["pool"] = pool
@@ -293,9 +290,7 @@ func (c *cmdCopy) copyInstance(conf *config.Config, sourceResource string, destR
 		}
 
 		// Allow setting additional config keys
-		for key, value := range configMap {
-			entry.Config[key] = value
-		}
+		maps.Copy(entry.Config, configMap)
 
 		// Allow setting device overrides
 		for k, m := range deviceMap {
@@ -310,15 +305,14 @@ func (c *cmdCopy) copyInstance(conf *config.Config, sourceResource string, destR
 				continue
 			}
 
-			for key, value := range m {
-				entry.Devices[k][key] = value
-			}
+			maps.Copy(entry.Devices[k], m)
 		}
 
 		// Allow overriding the ephemeral status
-		if ephemeral == 1 {
+		switch ephemeral {
+		case 1:
 			entry.Ephemeral = true
-		} else if ephemeral == 0 {
+		case 0:
 			entry.Ephemeral = false
 		}
 
@@ -446,11 +440,12 @@ func (c *cmdCopy) copyInstance(conf *config.Config, sourceResource string, destR
 	return nil
 }
 
+// Run runs the actual command logic.
 func (c *cmdCopy) Run(cmd *cobra.Command, args []string) error {
 	conf := c.global.conf
 
 	// Quick checks.
-	exit, err := c.global.CheckArgs(cmd, args, 1, 2)
+	exit, err := c.global.checkArgs(cmd, args, 1, 2)
 	if exit {
 		return err
 	}
