@@ -17,6 +17,7 @@ import (
 	"github.com/lxc/incus/v6/internal/instance"
 	"github.com/lxc/incus/v6/shared/api"
 	"github.com/lxc/incus/v6/shared/units"
+	"github.com/lxc/incus/v6/shared/util"
 )
 
 type cmdInfo struct {
@@ -636,16 +637,21 @@ func (c *cmdInfo) instanceInfo(d incus.InstanceServer, name string, showLog bool
 	fmt.Printf(i18n.G("Description: %s")+"\n", inst.Description)
 	fmt.Printf(i18n.G("Status: %s")+"\n", strings.ToUpper(inst.Status))
 
-	if inst.Type == "" {
-		inst.Type = "container"
+	instType := inst.Type
+	if instType == "" {
+		instType = "container"
+	}
+
+	if util.IsTrue(inst.ExpandedConfig["volatile.container.oci"]) {
+		instType = fmt.Sprintf("%s (%s)", instType, i18n.G("application"))
 	}
 
 	if inst.Ephemeral {
-		fmt.Printf(i18n.G("Type: %s (ephemeral)")+"\n", inst.Type)
-	} else {
-		fmt.Printf(i18n.G("Type: %s")+"\n", inst.Type)
+		instType = fmt.Sprintf("%s (%s)", instType, i18n.G("ephemeral"))
 	}
 
+	fmt.Printf(i18n.G("Type: %s")+"\n", instType)
+
 	fmt.Printf(i18n.G("Architecture: %s")+"\n", inst.Architecture)
 
 	if inst.Location != "" && d.IsClustered() {
