@@ -967,6 +967,7 @@ func projectDelete(d *Daemon, r *http.Request) response.Response {
 	}
 
 	var id int64
+	var projectConfig map[string]string
 	var usedBy []string
 	err = s.DB.Cluster.Transaction(r.Context(), func(ctx context.Context, tx *db.ClusterTx) error {
 		project, err := cluster.GetProject(ctx, tx.Tx(), name)
@@ -995,6 +996,11 @@ func projectDelete(d *Daemon, r *http.Request) response.Response {
 			return fmt.Errorf("Fetch project id %q: %w", name, err)
 		}
 
+		projectConfig, err = cluster.GetProjectConfig(ctx, tx.Tx(), int(id))
+		if err != nil {
+			return fmt.Errorf("Fetch project config %q: %w", name, err)
+		}
+
 		return nil
 	})
 	if err != nil {
@@ -1143,10 +1149,12 @@ func projectDelete(d *Daemon, r *http.Request) response.Response {
 			count--
 		}
 
-		// Empty the default profile.
-		err = target.UpdateProfile("default", api.ProfilePut{}, "")
-		if err != nil {
-			return response.InternalError(err)
+		// Empty the default profile, if the project owns one.
+		if util.IsTrue(projectConfig["features.profiles"]) {
+			err = target.UpdateProfile("default", api.ProfilePut{}, "")
+			if err != nil {
+				return response.InternalError(err)
+			}
 		}
 
 		// Delete images.
@@ -1187,6 +1195,17 @@ func projectDelete(d *Daemon, r *http.Request) response.Response {
 			count--
 		}
 
+		// Delete network address sets.
+		for _, networkAddressSetName := range entries["network-address-sets"] {
+			err := target.DeleteNetworkAddressSet(networkAddressSetName)
+			if err != nil {
+				return response.InternalError(err)
+			}
+
+			// Done deleting the network address set.
+			count--
+		}
+
 		// Delete network zones.
 		for _, networkZoneName := range entries["network-zones"] {
 			err := target.DeleteNetworkZone(networkZoneName)
