@@ -78,7 +78,7 @@ func ImageDownload(ctx context.Context, r *http.Request, s *state.State, op *ope
 	fp := alias
 
 	// Attempt to resolve the alias
-	if args.Server != "" && slices.Contains([]string{"incus", "lxd", "simplestreams"}, protocol) {
+	if args.Server != "" && slices.Contains([]string{"incus", "lxd", "oci", "simplestreams"}, protocol) {
 		clientArgs := &incus.ConnectionArgs{
 			TLSServerCert: args.Certificate,
 			UserAgent:     version.UserAgent,
@@ -101,7 +101,13 @@ func ImageDownload(ctx context.Context, r *http.Request, s *state.State, op *ope
 			if ok {
 				remote = server.UseProject(args.SourceProjectName)
 			}
-		} else {
+		} else if protocol == "oci" {
+			// Setup OCI client
+			remote, err = incus.ConnectOCI(args.Server, clientArgs)
+			if err != nil {
+				return nil, false, fmt.Errorf("Failed to connect to oci server %q: %w", args.Server, err)
+			}
+		} else if protocol == "simplestreams" {
 			// Setup simplestreams client
 			remote, err = incus.ConnectSimpleStreams(args.Server, clientArgs)
 			if err != nil {
@@ -111,7 +117,7 @@ func ImageDownload(ctx context.Context, r *http.Request, s *state.State, op *ope
 
 		// For public images, handle aliases and initial metadata
 		if args.Secret == "" {
-			// Look for a matching alias
+			// Look for a matching alias.  Note, this err message is lost!
 			entry, _, err := remote.GetImageAliasType(args.Type, fp)
 			if err == nil {
 				fp = entry.Target
@@ -346,7 +352,7 @@ func ImageDownload(ctx context.Context, r *http.Request, s *state.State, op *ope
 		op.SetCanceler(canceler)
 	}
 
-	if slices.Contains([]string{"incus", "lxd", "simplestreams"}, protocol) {
+	if slices.Contains([]string{"incus", "lxd", "oci", "simplestreams"}, protocol) {
 		// Create the target files
 		dest, err := os.Create(destName)
 		if err != nil {
