@@ -1,6 +1,8 @@
 package main
 
 import (
+	"slices"
+
 	"github.com/lxc/incus/v6/internal/server/cluster"
 	"github.com/lxc/incus/v6/internal/server/db"
 	"github.com/lxc/incus/v6/internal/server/state"
@@ -15,15 +17,12 @@ func networkUpdateOVNChassis(s *state.State, heartbeatData *cluster.APIHeartbeat
 	hasOVNChassis := false
 	localOVNChassis := false
 	for _, n := range heartbeatData.Members {
-		for _, role := range n.Roles {
-			if role == db.ClusterRoleOVNChassis {
-				if n.Address == localAddress {
-					localOVNChassis = true
-				}
-
-				hasOVNChassis = true
-				break
+		if slices.Contains(n.Roles, db.ClusterRoleOVNChassis) {
+			if n.Address == localAddress {
+				localOVNChassis = true
 			}
+
+			hasOVNChassis = true
 		}
 	}
 
