@@ -7,10 +7,10 @@ import (
 	"github.com/gorilla/mux"
 
 	"github.com/lxc/incus/v6/internal/server/auth"
-	"github.com/lxc/incus/v6/internal/server/resources"
 	"github.com/lxc/incus/v6/internal/server/response"
 	storagePools "github.com/lxc/incus/v6/internal/server/storage"
 	"github.com/lxc/incus/v6/shared/api"
+	"github.com/lxc/incus/v6/shared/resources"
 )
 
 var api10ResourcesCmd = APIEndpoint{
