@@ -250,6 +250,18 @@ var InstanceConfigKeysAny = map[string]func(value string) error{
 		return nil
 	},
 
+	// gendoc:generate(entity=instance, group=resource-limits, key=limits.memory.oom_priority)
+	// Specify an integer between -1000 and 1000.
+	// A negative value makes the instance less likely to be killed by the Out Of Memory killer,
+	// while a positive value makes it more likely to be killed.
+	// The default value of 0 means no adjustment to the Out Of Memory score.
+	// ---
+	//	type: integer
+	//	defaultdesc: `0`
+	//	liveupdate: yes
+	//	shortdesc: Out Of Memory killer priority adjustment for the instance
+	"limits.memory.oom_priority": validate.Optional(validate.IsOOMPriority),
+
 	// gendoc:generate(entity=instance, group=migration, key=migration.stateful)
 	// Enabling this option prevents the use of some features that are incompatible with it.
 	// ---
@@ -664,6 +676,42 @@ var InstanceConfigKeysContainer = map[string]func(value string) error{
 	//  shortdesc: Required driver version
 	"nvidia.require.driver": validate.IsAny,
 
+	// gendoc:generate(entity=instance, group=oci, key=oci.entrypoint)
+	// Override the entry point of an OCI container.
+	// ---
+	//  type: string
+	//  liveupdate: no
+	//  condition: OCI container
+	//  shortdesc: OCI container entry point
+	"oci.entrypoint": validate.IsAny,
+
+	// gendoc:generate(entity=instance, group=oci, key=oci.cwd)
+	// Override the working directory of an OCI container.
+	// ---
+	//  type: string
+	//  liveupdate: no
+	//  condition: OCI container
+	//  shortdesc: OCI container working directory
+	"oci.cwd": validate.Optional(validate.IsAbsFilePath),
+
+	// gendoc:generate(entity=instance, group=oci, key=oci.gid)
+	// Override the GID of the process run in an OCI container.
+	// ---
+	//  type: string
+	//  liveupdate: no
+	//  condition: OCI container
+	//  shortdesc: OCI container GID
+	"oci.gid": validate.Optional(validate.IsUint32),
+
+	// gendoc:generate(entity=instance, group=oci, key=oci.uid)
+	// Override the UID of the process run in an OCI container.
+	// ---
+	//  type: string
+	//  liveupdate: no
+	//  condition: OCI container
+	//  shortdesc: OCI container UID
+	"oci.uid": validate.Optional(validate.IsUint32),
+
 	// Caller is responsible for full validation of any raw.* value.
 
 	// gendoc:generate(entity=instance, group=raw, key=raw.lxc)
@@ -898,6 +946,14 @@ var InstanceConfigKeysContainer = map[string]func(value string) error{
 
 	"security.syscalls.whitelist": validate.IsAny,
 
+	// gendoc:generate(entity=instance, group=volatile, key=volatile.container.oci)
+	//
+	// ---
+	//  type: bool
+	//  defaultdesc: `false`
+	//  shortdesc: Whether the container is an OCI application container
+	"volatile.container.oci": validate.IsBool,
+
 	// gendoc:generate(entity=instance, group=volatile, key=volatile.last_state.idmap)
 	//
 	// ---
