@@ -4,6 +4,7 @@ import (
 	"bufio"
 	"errors"
 	"io/fs"
+	"maps"
 	"os"
 	"path/filepath"
 	"strings"
@@ -407,9 +408,7 @@ func Init() {
 				hasV2Root = true
 				break
 			} else {
-				for k, v := range unifiedControllers {
-					cgControllers[k] = v
-				}
+				maps.Copy(cgControllers, unifiedControllers)
 			}
 		}
 
