@@ -667,12 +667,16 @@ func NotifyHeartbeat(state *state.State, gateway *Gateway) {
 	wg.Wait()
 }
 
-// Rebalance the raft cluster, trying to see if we have a spare online node
-// that we can promote to voter node if we are below membershipMaxRaftVoters,
-// or to standby if we are below membershipMaxStandBys.
+// Rebalance adjusts raft node roles to maintain cluster membership limits.
 //
-// If there's such spare node, return its address as well as the new list of
-// raft nodes.
+//   - Incus nodes with the 'database-client' role are mapped to the raft
+//     'spare' role during rebalancing.
+//   - If we are below membershipMaxRaftVoters, promote a node to 'voter'.
+//   - If we are below membershipMaxStandBys, promote a node to 'standby'.
+//
+// Returns:
+// - the address of the node that was promoted or demoted (if any).
+// - and the full list of raft nodes after rebalancing.
 func Rebalance(state *state.State, gateway *Gateway, unavailableMembers []string) (string, []db.RaftNode, error) {
 	// If we're a standalone node, do nothing.
 	if gateway.memoryDial != nil {
@@ -684,6 +688,47 @@ func Rebalance(state *state.State, gateway *Gateway, unavailableMembers []string
 		return "", nil, fmt.Errorf("Get current raft nodes: %w", err)
 	}
 
+	var members []db.NodeInfo
+	err = state.DB.Cluster.Transaction(context.TODO(), func(ctx context.Context, tx *db.ClusterTx) error {
+		members, err = tx.GetNodes(ctx)
+		if err != nil {
+			return err
+		}
+
+		return nil
+	})
+	if err != nil {
+		return "", nil, fmt.Errorf("Get current members: %w", err)
+	}
+
+	// Prepare a map that stores node information by address.
+	membersInfo := map[string]db.NodeInfo{}
+	for _, member := range members {
+		membersInfo[member.Address] = member
+	}
+
+	for i, n := range nodes {
+		// If no member has this address, continue searching. This should not happen.
+		member, ok := membersInfo[n.Address]
+		if !ok {
+			continue
+		}
+
+		// Check if the node has the 'database-client' role.
+		if !slices.Contains(member.Roles, db.ClusterRoleDatabaseClient) {
+			continue
+		}
+
+		// If the node already has the 'spare' role, do nothing.
+		if n.Role == db.RaftSpare {
+			continue
+		}
+
+		nodes[i].Role = db.RaftSpare
+
+		return n.Address, nodes, nil
+	}
+
 	roles, err := newRolesChanges(state, gateway, nodes, unavailableMembers)
 	if err != nil {
 		return "", nil, err
@@ -692,12 +737,26 @@ func Rebalance(state *state.State, gateway *Gateway, unavailableMembers []string
 	role, candidates := roles.Adjust(gateway.info.ID)
 
 	if role == -1 {
-		// No node to promote
+		// No node to process.
 		return "", nodes, nil
 	}
 
 	// Check if we have a spare node that we can promote to the missing role.
-	candidateAddress := candidates[0].Address
+	candidateAddress := ""
+	for _, candidate := range candidates {
+		// If no member has this address, continue searching. This should not happen.
+		member, ok := membersInfo[candidate.Address]
+		if !ok {
+			continue
+		}
+
+		// Exclude nodes with the "database-client" role from candidates.
+		if slices.Contains(member.Roles, db.ClusterRoleDatabaseClient) {
+			continue
+		}
+
+		candidateAddress = candidate.Address
+	}
 
 	for i, node := range nodes {
 		if node.Address == candidateAddress {
