@@ -1,6 +1,7 @@
 package config
 
 import (
+	"errors"
 	"fmt"
 	"reflect"
 	"sort"
@@ -43,20 +44,20 @@ func Load(schema Schema, values map[string]string) (Map, error) {
 func (m *Map) Change(changes map[string]string) (map[string]string, error) {
 	values := make(map[string]string, len(m.schema))
 
-	errors := ErrorList{}
+	errList := &ErrorList{}
 	for name, change := range changes {
 		// Ensure that we were actually passed a string.
 		s := reflect.ValueOf(change)
 		if s.Kind() != reflect.String {
-			errors.add(name, nil, fmt.Sprintf("invalid type %s", s.Kind()))
+			errList.add(name, nil, fmt.Sprintf("invalid type %s", s.Kind()))
 			continue
 		}
 
 		values[name] = change
 	}
 
-	if errors.Len() > 0 {
-		return nil, errors
+	if errList.Len() > 0 {
+		return nil, errList
 	}
 
 	// Any key not explicitly set, is considered unset.
@@ -107,6 +108,20 @@ func (m *Map) GetRaw(name string) string {
 	if internalInstance.IsUserConfig(name) {
 		return value
 	}
+
+	if IsLoggingConfig(name) {
+		if !ok {
+			key, err := GetLoggingRuleForKey(name)
+			if err != nil {
+				panic(err)
+			}
+
+			value = key.Default
+		}
+
+		return value
+	}
+
 	// Schema key
 	key := m.schema.mustGetKey(name)
 	if !ok {
@@ -118,7 +133,7 @@ func (m *Map) GetRaw(name string) string {
 
 // GetString returns the value of the given key, which must be of type String.
 func (m *Map) GetString(name string) string {
-	if !internalInstance.IsUserConfig(name) {
+	if !internalInstance.IsUserConfig(name) && !IsLoggingConfig(name) {
 		m.schema.assertKeyType(name, String)
 	}
 
@@ -133,7 +148,10 @@ func (m *Map) GetBool(name string) bool {
 
 // GetInt64 returns the value of the given key, which must be of type Int64.
 func (m *Map) GetInt64(name string) int64 {
-	m.schema.assertKeyType(name, Int64)
+	if !IsLoggingConfig(name) {
+		m.schema.assertKeyType(name, Int64)
+	}
+
 	n, err := strconv.ParseInt(m.GetRaw(name), 10, 64)
 	if err != nil {
 		panic(fmt.Sprintf("cannot convert to int64: %v", err))
@@ -156,12 +174,12 @@ func (m *Map) update(values map[string]string) ([]string, error) {
 
 	// Update our keys with the values from the given map, and keep track
 	// of which keys actually changed their value.
-	errors := ErrorList{}
+	errList := &ErrorList{}
 	names := []string{}
 	for name, value := range values {
 		changed, err := m.set(name, value, initial)
 		if err != nil {
-			errors.add(name, value, err.Error())
+			errList.add(name, value, err.Error())
 			continue
 		}
 
@@ -172,9 +190,9 @@ func (m *Map) update(values map[string]string) ([]string, error) {
 	sort.Strings(names)
 
 	var err error
-	if errors.Len() > 0 {
-		errors.sort()
-		err = errors
+	if errList.Len() > 0 {
+		errList.sort()
+		err = errList
 	}
 
 	return names, err
@@ -189,7 +207,7 @@ func (m *Map) set(name string, value string, initial bool) (bool, error) {
 		for _, r := range strings.TrimPrefix(name, "user.") {
 			// Only allow letters, digits, and punctuation characters.
 			if !unicode.In(r, unicode.Letter, unicode.Digit, unicode.Punct) {
-				return false, fmt.Errorf("Invalid key name")
+				return false, errors.New("Invalid key name")
 			}
 		}
 
@@ -208,9 +226,18 @@ func (m *Map) set(name string, value string, initial bool) (bool, error) {
 		return true, nil
 	}
 
+	if IsLoggingConfig(name) {
+		rule, err := GetLoggingRuleForKey(name)
+		if err != nil {
+			return false, err
+		}
+
+		m.schema[name] = rule
+	}
+
 	key, ok := m.schema[name]
 	if !ok {
-		return false, fmt.Errorf("unknown key")
+		return false, errors.New("unknown key")
 	}
 
 	// When unsetting a config key, the value argument will be empty.
