@@ -1658,3 +1658,13 @@ func (d Xtables) NetworkApplyForwards(networkName string, rules []AddressForward
 
 	return nil
 }
+
+// NetworkApplyAddressSets isn't supported under xtables.
+func (d Xtables) NetworkApplyAddressSets(sets []AddressSet, nftTable string) error {
+	return errors.New("Address sets aren't supported by xtables firewalling")
+}
+
+// NetworkDeleteAddressSetsIfUnused  isn't supported under xtables.
+func (d Xtables) NetworkDeleteAddressSetsIfUnused(nftTable string) error {
+	return errors.New("Address sets aren't supported by xtables firewalling")
+}
