@@ -72,7 +72,7 @@ const VolumeTypeVM = VolumeType("virtual-machines")
 // ContentType indicates the format of the volume.
 type ContentType string
 
-// ContentTypeFS indicates the volume will be populated with a mountabble filesystem.
+// ContentTypeFS indicates the volume will be populated with a mountable filesystem.
 const ContentTypeFS = ContentType("filesystem")
 
 // ContentTypeBlock indicates the volume will be a block device and its contents and we do not
@@ -150,7 +150,7 @@ func (v Volume) ExpandedConfig(key string) string {
 // NewSnapshot instantiates a new Volume struct representing a snapshot of the parent volume.
 func (v Volume) NewSnapshot(snapshotName string) (Volume, error) {
 	if v.IsSnapshot() {
-		return Volume{}, fmt.Errorf("Cannot create a snapshot volume from a snapshot")
+		return Volume{}, errors.New("Cannot create a snapshot volume from a snapshot")
 	}
 
 	fullSnapName := GetSnapshotVolumeName(v.name, snapshotName)
@@ -209,11 +209,12 @@ func (v Volume) MountInUse() bool {
 
 // EnsureMountPath creates the volume's mount path if missing, then sets the correct permission for the type.
 // If permission setting fails and the volume is a snapshot then the error is ignored as snapshots are read only.
-func (v Volume) EnsureMountPath() error {
+// The boolean flag indicates whether this is being called during volume creation.
+func (v Volume) EnsureMountPath(creation bool) error {
 	volPath := v.MountPath()
 
-	revert := revert.New()
-	defer revert.Fail()
+	reverter := revert.New()
+	defer reverter.Fail()
 
 	// Create volume's mount path if missing, with any created directories set to 0711.
 	if !util.PathExists(volPath) {
@@ -231,12 +232,13 @@ func (v Volume) EnsureMountPath() error {
 			return fmt.Errorf("Failed to create mount directory %q: %w", volPath, err)
 		}
 
-		revert.Add(func() { _ = os.Remove(volPath) })
+		reverter.Add(func() { _ = os.Remove(volPath) })
 	}
 
-	mode := os.FileMode(0o711)
-	if v.volType == VolumeTypeCustom && v.contentType == ContentTypeFS {
+	// If dealing with a custom volume and part of volume creation, apply initial mode and owner.
+	if v.volType == VolumeTypeCustom && v.contentType == ContentTypeFS && creation {
 		initialMode := v.ExpandedConfig("initial.mode")
+		mode := os.FileMode(0o711)
 		if initialMode != "" {
 			m, err := strconv.ParseInt(initialMode, 8, 0)
 			if err != nil {
@@ -246,8 +248,12 @@ func (v Volume) EnsureMountPath() error {
 			mode = os.FileMode(m)
 		}
 
+		err := os.Chmod(volPath, mode)
+		if err != nil {
+			return err
+		}
+
 		uid, gid := 0, 0
-		var err error
 		initialUID := v.ExpandedConfig("initial.uid")
 		if initialUID != "" {
 			uid, err = strconv.Atoi(initialUID)
@@ -275,30 +281,30 @@ func (v Volume) EnsureMountPath() error {
 
 	// Set very restrictive mode 0100 for non-custom, non-bucket and non-image volumes.
 	if v.volType != VolumeTypeCustom && v.volType != VolumeTypeImage && v.volType != VolumeTypeBucket {
-		mode = os.FileMode(0o100)
-	}
+		mode := os.FileMode(0o100)
 
-	fInfo, err := os.Lstat(volPath)
-	if err != nil {
-		return fmt.Errorf("Error getting mount directory info %q: %w", volPath, err)
-	}
+		fInfo, err := os.Lstat(volPath)
+		if err != nil {
+			return fmt.Errorf("Error getting mount directory info %q: %w", volPath, err)
+		}
 
-	// We expect the mount path to be a directory, so use this for comparison.
-	compareMode := os.ModeDir | mode
+		// We expect the mount path to be a directory, so use this for comparison.
+		compareMode := os.ModeDir | mode
 
-	// Set mode of actual volume's mount path if needed.
-	if fInfo.Mode() != compareMode {
-		err = os.Chmod(volPath, mode)
+		// Set mode of actual volume's mount path if needed.
+		if fInfo.Mode() != compareMode {
+			err = os.Chmod(volPath, mode)
 
-		// If the chmod failed, return the error as long as the volume is not a snapshot.
-		// If the volume is a snapshot, we must ignore the error as snapshots are readonly and cannot be
-		// modified after they are taken, such that any permission error is not fixable at mount time.
-		if err != nil && !v.IsSnapshot() {
-			return fmt.Errorf("Failed to chmod mount directory %q (%04o): %w", volPath, mode, err)
+			// If the chmod failed, return the error as long as the volume is not a snapshot.
+			// If the volume is a snapshot, we must ignore the error as snapshots are readonly and cannot be
+			// modified after they are taken, such that any permission error is not fixable at mount time.
+			if err != nil && !v.IsSnapshot() {
+				return fmt.Errorf("Failed to chmod mount directory %q (%04o): %w", volPath, mode, err)
+			}
 		}
 	}
 
-	revert.Success()
+	reverter.Success()
 	return nil
 }
 
@@ -373,7 +379,7 @@ func (v Volume) UnmountTask(task func(op *operations.Operation) error, keepBlock
 // Snapshots returns a list of snapshots for the volume (in no particular order).
 func (v Volume) Snapshots(op *operations.Operation) ([]Volume, error) {
 	if v.IsSnapshot() {
-		return nil, fmt.Errorf("Volume is a snapshot")
+		return nil, errors.New("Volume is a snapshot")
 	}
 
 	snapshots, err := v.driver.VolumeSnapshots(v, op)
@@ -398,7 +404,7 @@ func (v Volume) Snapshots(op *operations.Operation) ([]Volume, error) {
 // necessarily in the same order).
 func (v Volume) SnapshotsMatch(snapNames []string, op *operations.Operation) error {
 	if v.IsSnapshot() {
-		return fmt.Errorf("Volume is a snapshot")
+		return errors.New("Volume is a snapshot")
 	}
 
 	snapshots, err := v.driver.VolumeSnapshots(v, op)
