@@ -426,7 +426,10 @@ var APIExtensions = []string{
 	"projects_force_delete",
 	"resources_cpu_flags",
 	"disk_io_bus_cache_filesystem",
+	"instance_oci",
+	"clustering_groups_config",
 	"instances_lxcfs_per_instance",
+	"clustering_groups_vm_cpu_definition",
 	"disk_volume_subpath",
 	"projects_limits_disk_pool",
 	"network_ovn_isolated",
@@ -471,6 +474,9 @@ var APIExtensions = []string{
 	"instance_state_cpu_time",
 	"network_io_bus",
 	"disk_io_bus_usb",
+	"storage_driver_linstor",
+	"instance_oci_entrypoint",
+	"network_address_set",
 	"server_logging",
 	"network_forward_snat",
 	"memory_hotplug",
@@ -487,6 +493,12 @@ var APIExtensions = []string{
 	"limits_memory_hotplug",
 	"disk_wwn",
 	"server_logging_webhook",
+	"storage_driver_truenas",
+	"container_disk_tmpfs",
+	"instance_limits_oom",
+	"backup_override_config",
+	"network_ovn_tunnels",
+	"init_preseed_cluster_groups",
 }
 
 // APIExtensionsCount returns the number of available API extensions.
