@@ -70,6 +70,10 @@ const (
 	EventLifecycleNetworkACLDeleted                 = "network-acl-deleted"
 	EventLifecycleNetworkACLRenamed                 = "network-acl-renamed"
 	EventLifecycleNetworkACLUpdated                 = "network-acl-updated"
+	EventLifecycleNetworkAddressSetCreated          = "network-address-set-created"
+	EventLifecycleNetworkAddressSetDeleted          = "network-address-set-deleted"
+	EventLifecycleNetworkAddressSetRenamed          = "network-address-set-renamed"
+	EventLifecycleNetworkAddressSetUpdated          = "network-address-set-updated"
 	EventLifecycleNetworkCreated                    = "network-created"
 	EventLifecycleNetworkDeleted                    = "network-deleted"
 	EventLifecycleNetworkForwardCreated             = "network-forward-created"
