@@ -38,6 +38,9 @@ available_storage_backends() {
     if [ -n "${INCUS_CEPH_CLUSTER:-}" ]; then
         storage_backends="${storage_backends} ceph"
     fi
+    if [ -n "${INCUS_LINSTOR_CLUSTER:-}" ]; then
+        storage_backends="${storage_backends} linstor"
+    fi
 
     for backend in $storage_backends; do
         if command -v "$backend" > /dev/null 2>&1; then
@@ -45,6 +48,10 @@ available_storage_backends() {
         fi
     done
 
+    if [ -n "${INCUS_TRUENAS_DATASET:-}" ] && command -v "truenas_incus_ctl" > /dev/null 2>&1; then
+        backends="$backends truenas"
+    fi
+
     echo "$backends"
 }
 
